<?php
/**
 * Hotelica functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Hotelica
 */

if ( ! function_exists( 'hotelica_setup' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */

	function hotelica_setup() {

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Hotelica, use a find and replace
		 * to change 'hotelica' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'hotelica', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'hotelica' ),
			'footer' => esc_html__( 'Footer', 'hotelica' ),
			'homepage' => esc_html__( 'Homepage', 'hotelica' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
		add_theme_support( 'custom-logo' );

		add_post_type_support( 'page', 'excerpt' );

		/**
		* Define image sizes
		*/

		add_image_size( 'hotelica_square', '300', '300', array( "1", "") ); 
		add_image_size( 'hotelica_medium', '800', '600', array( "1", "") ); 
		add_image_size( 'hotelica_packages', '800', '498', array( "1", "") ); 
		add_image_size( 'hotelica_thumbnail', '150', '100', array( "1", "") ); 
		add_image_size( 'hotelica_blog_list', '850', '400', array( "1", "") );		

	}

endif;

add_action( 'after_setup_theme', 'hotelica_setup' );

/**
* Add kirki in the theme
*/
if ( !class_exists( 'Kirki' ) ) {

	include_once( dirname( __FILE__ ) . '/inc/kirki/kirki.php' );

	add_filter( 'kirki/config', 'hotelica_kirki_update_url' );
	if ( !function_exists( 'my_theme_kirki_update_url' ) ) {
	    function hotelica_kirki_update_url( $config ) {
	        $config['url_path'] = get_stylesheet_directory_uri() . '/inc/kirki/';
	        return $config;
	    }
	}

}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function hotelica_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'hotelica_content_width', 640 );
}
add_action( 'after_setup_theme', 'hotelica_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function hotelica_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'hotelica' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'hotelica' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'hotelica_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function hotelica_scripts() {

	/**  
	* Enqueue CSS 
	*/

	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/bootstrap/css/bootstrap.min.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/icons/font-awesome/css/font-awesome.min.css' );
	wp_enqueue_style( 'flexslider', get_template_directory_uri() . '/css/flexslider.css' );
	wp_enqueue_style( 'google-fonts-raleway','https://fonts.googleapis.com/css?family=Raleway:400,300,500,600,700' );
	wp_enqueue_style( 'google-fonts-roboto','https://fonts.googleapis.com/css?family=Roboto:700,400,300,300italic' );
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.css' );
	wp_enqueue_style( 'hotelica-style', get_stylesheet_uri() );
	wp_enqueue_style( 'hotelica-style-2', get_template_directory_uri() . '/css/style.css' );

	/** 
	* Enqueue JS 
	*/
	
	wp_enqueue_script( 'hotelica-navigation', get_template_directory_uri() . '/js/navigation.js', array( 'jquery' ) ,false, true );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/bootstrap/js/bootstrap.min.js', array( 'jquery' ),false, true );
	wp_enqueue_script( 'hotelica-device', get_template_directory_uri() . '/js/device.min.js', array( 'jquery' ), false, false );
	

	wp_enqueue_script( 'waypoint', get_template_directory_uri() . '/js/waypoint.min.js', array( 'jquery' ) ,false, true );
	wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/js/jquery.flexslider-min.js', array( 'jquery' ) ,false, true );
	wp_enqueue_script( 'parallax', get_template_directory_uri() . '/js/jquery-parallax.min.js', array( 'jquery' ) ,false, true );
	wp_enqueue_script( 'matchheight', get_template_directory_uri() . '/js/jquery.matchHeight-min.js', array( 'jquery' ) ,false, true );
	wp_enqueue_script( 'countto', get_template_directory_uri() . '/js/jquery.countTo.min.js', array( 'jquery' ) ,false, true );
	wp_enqueue_script( 'slicknav', get_template_directory_uri() . '/js/jquery.slicknav.min.js', array( 'jquery' ) ,false, true );
	wp_enqueue_script( 'scrollbot', get_template_directory_uri() . '/js/scrollbot.min.js', array( 'jquery' ) ,false, true );

	
	wp_enqueue_script( 'slick', get_template_directory_uri() . '/js/slick.min.js', array( 'jquery' ) ,false, true);
	wp_enqueue_script( 'images-grid', get_template_directory_uri() . '/js/images-grid.js', array( 'jquery' ) ,false, true);

	wp_register_script( 'hotelica-custom-js', get_template_directory_uri() . '/js/customs.js', array( 'jquery' ) ,false, true );

	wp_localize_script( 'hotelica-custom-js', 'hotelica_object', hotelica_localize_script() );
	wp_enqueue_script( 'hotelica-custom-js' );

	wp_enqueue_script( 'hotelica-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), false, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}


}
add_action( 'wp_enqueue_scripts', 'hotelica_scripts' );

function hotelica_localize_script(){	

	$translation_array = array(
		'admin_bar_status' => is_admin_bar_showing() ? true : false,
		'gallery_images' => hotelica_get_gallery_images(),
		'ajax_url' => admin_url('admin-ajax.php'),
		'theme_url' => get_template_directory_uri(),
		'fill_required_fields_msg' => esc_html__( 'Please fill all the fields and try again.' , 'hotelica' ),
		'slider_mousewheel' => ( get_theme_mod( 'slider_mousewheel' , 'disable' ) == 'enable' ? true : false ),
		'slider_keyboard_navigation' => ( get_theme_mod( 'keyboard_navigation' , 'disable' ) == 'enable' ? true : false ),
		'slider_randomize' => ( get_theme_mod( 'slider_randomize' , 'disable' ) == 'enable' ? true : false ),
		'slider_animationSpeed' => absint( get_theme_mod( 'slider_animation_speed' , 600 ) ),
		'slider_slideshowSpeed' =>  absint( get_theme_mod( 'slider_slideshow_speed' , 7000 ) ),
	);

	return apply_filters( 'hotelica_localize_array', $translation_array );

}

function hotelica_get_gallery_images(){

	$galleries = get_theme_mod( 'gallery' );
	$image_attr = array();
	$data = array();
	$data['cells'] = 5;
	$data['align'] = true;

	if( !empty( $galleries ) && is_array( $galleries ) ){

		$data['cells'] = 5;
		$data['align'] = true;

		foreach ( $galleries as $key => $value ) {
			
			$image_attr[$key]['src'] = hotelica_get_image_by_attachment_id( $value['image'] , 'hotelica_medium' );
			$image_attr[$key]['alt'] = esc_attr( $value['title'] );
			$image_attr[$key]['title'] = esc_attr( $value['title'] );
			$image_attr[$key]['caption'] = esc_html( $value['title'] );
			$image_attr[$key]['thumbnail'] = hotelica_get_image_by_attachment_id( $value['image'] , 'hotelica_medium' );

		}	

		$data['images'] = $image_attr;

	}

	return $data;	

}

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

require get_template_directory() . '/wp-comment-walker.php';

function hotelica_get_post_categories(){

	$terms = get_terms( array(
	    'taxonomy' => 'category',
	    'hide_empty' => false,
	) );

	if( empty($terms) || !is_array( $terms ) ){
		return array();
	}

	$data = array();
	foreach ( $terms as $key => $value) {
		$term_id = absint( $value->term_id );
		$data[$term_id] =  esc_html( $value->name );
	}
	return $data;

}

function hotelica_get_image_by_attachment_id( $image_id , $size = 'thumbnail' , $return = false ){

	$image_attributes = wp_get_attachment_image_src( $image_id , $size );

	if( $image_attributes ){
		return esc_url( $image_attributes[0] );
	}
	return $return == false ? esc_url( get_template_directory_uri() . '/images/blank_profile.png' ) : '';

}

function hotelica_post_content($string, $wordsreturned = 10 )
{
    $retval = $string;  //  Just in case of a problem
    $array = explode(" ", $string);

    if (count($array)<=$wordsreturned)
    {
        $retval = $string;
    }

    else
    {
        array_splice($array, $wordsreturned);
        $retval = implode(" ", $array)." ...";
    }
    return $retval;
}

function hotelica_get_packages_homepage(){

	$packages_category_id = get_theme_mod( 'packages_category' , false );

	if( $packages_category_id == false ){
		return;
	}

	$args = array(
		'post_type' => 'post',
		'posts_per_page' => 2,
		'cat' => $packages_category_id,
		'post_status' => 'publish'
	);

	$query_packages = new WP_Query( $args ); 
	$count = 0;

	if( $query_packages->have_posts() ):

		while( $query_packages->have_posts() ): $query_packages->the_post(); 

			global $post;
			$post_id = $post->ID;

			if( $count%2 == 0 ){ ?>
				<li class="clearfix">                   	
					<div class="row">
				<?php 

			} ?>
					
			<div class="col-md-6 col-sm-6">
				<div class="best">
					<div class="featured-img">
						
						<?php 
						if( has_post_thumbnail() ){
							the_post_thumbnail( 'hotelica_packages' , array( 'title' => esc_attr( get_the_title() ) ) ); 
						} ?>

						<div class="best-package-module">
							<h3><a href="javascript:void(0)"><?php the_title(); ?></a></h3>
					
							<p><?php echo esc_html( hotelica_post_content( sanitize_text_field( get_the_content() ) , 25 ) ); ?></p>

							<div class="bottom">
							
								<span class="price">

									<span class="large">

										<?php 
										$price = get_post_meta( $post_id, 'price', true ); 
										echo absint( $price ); ?>
										
									</span> 
									<span class="small">

										<?php 
										echo esc_html( get_theme_mod( 'theme_currency', 'USD' ) ); ?>
											
									</span>
								</span>
								
								<a href="javascript:void(0)" class="link-more book_now_package" data-post-id="<?php echo absint( $post_id ); ?>"><?php esc_html_e( 'More Details' , 'hotelica' ); ?></a>
						
							</div>

						</div>
						
					</div>
				</div>
			</div>
			
			<?php
			if( $count%2 != 0 || 
				$query_packages->current_post +1 == $query_packages->post_count ){ ?>
				</div></li>
				<?php 
			} 
			$count++;
		endwhile;

		wp_reset_postdata();

	endif;

}

function hotelica_get_rooms_homepage( $return = true ){

	$room_category_id = get_theme_mod( 'room_listing_category' , false );

	if( $room_category_id == false ){
		return;
	}

	$args = array(
		'post_type' => 'post',
		'posts_per_page' => 4,
		'cat' => $room_category_id,
		'post_status' => 'publish'
	);

	$query_room = new WP_Query( $args ); 
	$content = '';
	$total_rooms = $query_room->found_posts;

	$count_delay = 0;
	if( $query_room->have_posts() ):

		while( $query_room->have_posts() ): $query_room->the_post(); 

			global $post;
			$post_id = $post->ID;
			$count_delay += 0.2; ?>

			<div class="col-sm-6">
				<div class="hotel-room-item-02 wow fadeInDown" data-wow-delay="<?php echo esc_attr( $count_delay ); ?>s">
					<div class="img">
						
						<?php 
						if( has_post_thumbnail() ){
							the_post_thumbnail( 'hotelica_medium', array( 'title' => esc_attr( get_the_title() ) ) );
						}
						?>
						
					</div>
					<article class="content">
						<h3><?php the_title(); ?></h3>
						
						<p><?php echo esc_html( hotelica_post_content( sanitize_text_field( get_the_content() ) , 10 ) ); ?></p>
						
						<hr />
						
						<div class="bottom">
							
							<span class="price">

								<?php 
								$price = get_post_meta( $post_id, 'price', true ); 
								echo absint( $price ); ?>

								<span class="small">
									<?php echo esc_html( get_theme_mod( 'theme_currency', 'USD' ) ); ?>
								</span>
							</span>
							
							<a href="javascript:void(0)" class="link-more book_now_package" data-post-id="<?php echo absint( $post_id ); ?>"><?php esc_html_e( 'Read More', 'hotelica' ); ?></a>
							
						</div>
					</article>
				</div>

			</div>

			<?php

		endwhile;

		wp_reset_postdata();

	endif;

}

function hotelica_get_discount_text(){

	$text = get_theme_mod( 'special_package_discount' );
    $data = explode( '|', $text , 2 );

    if( is_array( $data ) ){ ?>

    	<div class="inner">
			<span class="large">
				<?php echo esc_html( $data[0] ); ?>
			</span>
			<?php 
			if( !empty( $data[1] ) ){
				echo esc_html( $data[1] );
			} ?>
		</div>

    	<?php
    }

}

function hotelica_get_blog_posts(){

	$blog_category_id = get_theme_mod( 'blog_category' , false );

	if( $blog_category_id == false ){
		return;
	}

	$args = array(
		'post_type' => 'post',
		'posts_per_page' => 4,
		'cat' => $blog_category_id,
		'post_status' => 'publish'
	);

	$query_blog = new WP_Query( $args ); 
	$animation_count = 0;

	if( $query_blog->have_posts() ):

		while( $query_blog->have_posts() ): $query_blog->the_post(); 

			global $post;

			$animation_count += 0.2; ?>

			<div class="col-xs-3 col-sm-3 blog_wrap wow fadeIn" data-wow-delay="<?php echo esc_attr( $animation_count ); ?>s">
				<a href="<?php the_permalink(); ?>">
					<div class="blog-item">
						<?php 
						the_post_thumbnail( 'hotelica_medium' , array( 'title' => esc_attr( get_the_title() ) ) );
						?>
						<div class="blog-content">
							<h4><?php the_title(); ?></h4>
							<p><?php echo esc_html( hotelica_post_content( sanitize_text_field( get_the_content() ) , 20 ) ); ?></p>
							<div class="listin">
								<span><i class="fa fa-calendar"></i><?php echo get_the_date(); ?></span>
								<span><i class="fa fa-comment"></i>
								<?php 
								$no_of_comments = get_comments_number( $post->ID );

								if( $no_of_comments < 1 ){
									printf( 
										/* translators: %d is replaced with "number". It will get the comment numbers for a post */
										esc_html__( '%d Comment', 'hotelica' ), absint( $no_of_comments )
									);
								} else {
									
									printf( 
										/* translators: %d is replaced with "number". It will get the comment numbers for a post */
										_nx( 
											'%d Comment', 
											'%d Comments', 
											absint( $no_of_comments ), 
											'no of comments',
											'hotelica' 
										), 
										absint( $no_of_comments )
									);
									
								}
								?></span>
							</div>
						</div>
					</div>
				</a>
			</div>

		<?php

		endwhile;

		wp_reset_postdata();

	endif;

}

function hotelica_get_logo(){ 

	$logo_id = get_theme_mod( 'custom_logo' ); ?>

	<header id="header" class="site-header" role="banner">
		
		<?php 
		if( !empty( $logo_id ) ){ ?>
			<div class="logo">
				<a href="<?php echo esc_url( home_url() ); ?>">
					<img src="<?php echo esc_url( wp_get_attachment_url( get_theme_mod( 'custom_logo' ) ) ); ?>" alt="<?php esc_attr_e( 'Logo' , 'hotelica' ); ?>" />
				</a>
			</div>
			<?php 
		} else { ?>
			<div class="site-branding">
				<h1 class="site-title">
					<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
						<?php bloginfo( 'name' ); ?>
					</a>
				</h1>
				<p class="site-description"><?php echo esc_html( get_bloginfo( 'description' ) ); ?></p>
			</div>
			<?php
		}?>
		
	</header>

	<?php
}

add_action( 'wp_ajax_hotelica_get_package_details' , 'hotelica_get_package_details' );
add_action( 'wp_ajax_nopriv_hotelica_get_package_details' , 'hotelica_get_package_details' );

function hotelica_get_package_details(){

	$data = array_map( 'sanitize_text_field' , $_POST );
	$post_id = $data['post_id'];
	$content = '';

	$images = hotelica_get_post_gallery_url( $post_id );
	$gallery_status = false;

	ob_start();

	if( !empty( $images ) ){ 

		$gallery_status = true; ?>

		<div class="col-sm-6">

			<div class="slider slider-for-2">

				<?php
				foreach ( $images as $key => $value) {
				 	echo '<div><img src="' . esc_url( $value['large'] ) . '"></div>';
				} ?>

			</div>

			<div class="slider slider-nav-2">

				<?php
				foreach ( $images as $key => $value) {
				 	echo '<div>
					<div class="image">
						<img src="' . esc_url( $value['thumbnail'] ) . '">
					</div>
				</div>';
				} ?>			

			</div>

		</div>

		<?php
	} ?>

	<div class="<?php echo ( $gallery_status == true ? 'col-sm-6' : 'col-sm-12' ); ?>">

    	<?php 
    	do_action( 'hotelica_before_modal_content' );
    	?>

		<div class="panel with-nav-tabs panel-warning">
			<div class="panel-body">
				<div class="tab-content">
					<div class="tab-pane fade in active" id="tab1warning">
						<div class="package-module">
						<h3><?php echo esc_html( get_the_title( $post_id ) ); ?></h3>

							<div class="modal_package_content">
								<p><?php echo wp_kses_post( wpautop( get_post_field( 'post_content', $post_id ) ) ); ?></p>
							</div>	

							<div class="bottom">

								<span class="price">

									<span class="large">
										<?php 
										$price = get_post_meta( $post_id, 'price', true ); 
										echo absint( $price ); ?>
									</span> 

									<span class="small">
										<?php 
										echo esc_html( get_theme_mod( 'theme_currency', 'USD' ) ); ?>
									</span>

								</span>

							</div>
						</div>
					</div>
					<?php 
			    	do_action( 'hotelica_after_package_content' , $data );
			    	?>
				</div>
			</div>
		</div>
	</div>

	<?php

	$content = ob_get_clean();

	echo json_encode(
		array(
			'status' => 'success',
			'content' => $content
		)
	);

	die;

}

function hotelica_get_post_gallery_url( $post_id ){

	$galleries_string = get_post_meta( $post_id, 'gallery', true );
	$galleries_array = array_filter(explode( ',', $galleries_string ));
	$data = array();

	if( !empty( $galleries_array ) && is_array( $galleries_array ) ){

		foreach ( $galleries_array as $key => $image_id ) {
			
			$data[$key]['thumbnail'] = esc_url( hotelica_get_image_by_attachment_id( $image_id, 'hotelica_thumbnail' , true ) );
			$data[$key]['large'] = esc_url( hotelica_get_image_by_attachment_id( $image_id, 'hotelica_medium' , true ) );

		}

	}

	return $data;

}

function hotelica_get_body_class(){

	if( !is_page_template( 'page-templates/homepage.php' ) ){
		return 'sidebar';
	}
	return;

}

function hotelica_menus(){ ?>

	<!-- =========================
	  STICKY MENY
	============================== -->
	<!-- start Navbar (Header) -->
	<nav class="navbar navbar-default navbar-fixed-top with-slicknav">

		<div id="navbar" class="collapse navbar-collapse navbar-arrow">
			<div class="container">

				<?php wp_nav_menu( array(
					'theme_location' => 'primary',
					'container' => 'ul',
				    'menu_id' => 'responsive-menu',
				    'menu_class'=> 'nav navbar-nav pull-left',
				)); ?>

			</div>

		</div><!--/.nav-collapse -->

		<div id="slicknav-mobile"></div>

	</nav>
	<!-- end Navbar (Header) -->

	<?php
}

/**
* Breadcrumbs Section
*/

function hotelica_breadcrums(){ 

	$class = is_home() ? 'blog_home_breadcrum' : 'not_blog_home'; ?>

	<div class="breadcrumb-wrapper <?php echo esc_attr( $class ); ?>">
		<div class="section-title">
			<ol class="breadcrumb">
				<?php 
				hotelica_custom_breadcrumbs(); 
				?>
			</ol>
		</div>
		<div class="overlay"></div>
	</div>

	<?php
}

/**
* Breadcrumbs
*/

function hotelica_custom_breadcrumbs() {
       
    // Settings
    $separator          = '/';
    $breadcrums_id      = 'breadcrumbs';
    $breadcrums_class   = 'breadcrumbs';
    $home_title         = esc_html__( 'Home' , 'hotelica' );;
      
    // If you have any custom post types with custom taxonomies, put the taxonomy name below (e.g. product_cat)
    $custom_taxonomy    = 'destinations';
       
    // Get the query & post information
    global $post,$wp_query;
       
    // Do not display on the homepage
    if ( !is_front_page() ) {
           
        // Home page
        echo '<li class="item-home hotelica-home"><a class="bread-link bread-home" href="' . esc_url( home_url() ) . '">' . esc_html( $home_title ) . '</a></li>';
        
        if ( is_single() ) {
              
            // Get post category info
            $category = get_the_category();

            if(!empty($category)) {
              
                // Get last category post is in
                $last_category =array_pop((array_slice($category, -1)));
                  
                // Get parent any categories and create array
                $get_cat_parents = rtrim(get_category_parents($last_category->term_id, true, ','),',');
                $cat_parents = explode(',',$get_cat_parents);
                  
                // Loop through parent categories and store in variable $cat_display
                $cat_display = '';
                foreach($cat_parents as $parents) {
                    $cat_display .= '<li class="item-cat">'. wp_kses_post( $parents ) .'</li>';
                    //$cat_display .= '<li class="separator"> ' . $separator . ' </li>';
                }
             
            }
              
            // If it's a custom post type within a custom taxonomy
            $taxonomy_exists = taxonomy_exists($custom_taxonomy);
            if(empty($last_category) && !empty($custom_taxonomy) && $taxonomy_exists) {
                   
                $taxonomy_terms = get_the_terms( $post->ID, $custom_taxonomy );

                if( !empty( $taxonomy_terms ) && is_array( $taxonomy_terms ) ){

                	$cat_id         = $taxonomy_terms[0]->term_id;
	                $cat_nicename   = $taxonomy_terms[0]->slug;
	                $cat_link       = get_term_link($taxonomy_terms[0]->term_id, $custom_taxonomy);
	                $cat_name       = $taxonomy_terms[0]->name;

                }
                
            }
              
            // Check if the post is in a category
            if(!empty($last_category)) {

                $allowed_html = array(
                	'li' => array(
                		'class' => array()
                	),
                	'a' => array(
                		'href' => array()
                	)
                );

                echo wp_kses( $cat_display , $allowed_html );
                echo '<li class="item-current"><span class="bread-current active">' . esc_html( get_the_title() ) . '</span></li>';
                  
            // Else if post is in a custom taxonomy
            } else if(!empty($cat_id)) {
                  
                echo '<li class="item-cat"><a class="bread-cat" href="' . esc_url( $cat_link ) . '">' . esc_html( $cat_name ) . '</a></li>';

                echo '<li class="item-current"><span class="active bread-current">' . esc_html( get_the_title() ) . '</span></li>';
              
            } else {
                  
                echo '<li class="item-current"><span class="active bread-current">' . esc_html( get_the_title() ) . '</span></li>';
                  
            }
              
        } elseif ( is_category() ) {
               
            // Category page
            echo '<li class="item-current item-cat"><span class="active bread-current bread-cat">' . single_cat_title('', false) . '</span></li>';
               
        } elseif ( is_page() ) {
               
            // Standard page
            if( $post->post_parent ){
                   
                // If child page, get parents 
                $anc = get_post_ancestors( $post->ID );
                $parents = '';
                   
                // Get parents in the right order
                $anc = array_reverse($anc);
                   
                // Parent page loop
                foreach ( $anc as $ancestor ) {
                    $parents .= '<li class="item-parent"><a class="bread-parent" href="' . esc_url( get_permalink($ancestor) ) . '">' . esc_html( get_the_title($ancestor) ) . '</a></li>';
                }
                   
                // Display parent pages

                echo wp_kses( 
                	$parents, 
                	array(
                		'li' => array(
                			'class' => array()
                		),
                		'a' => array(
                			'class' => array(),
                			'href' => array(),
                			'title' => array()
                		),
                	)
                );
                   
                // Current page
                echo '<li class="item-current"><span class="active"> ' . esc_html( get_the_title() ) . '</span></li>';
                   
            } else {
                   
                // Just display current page if not parents
                echo '<li class="item-current"><span class="active bread-current">' . esc_html( get_the_title() ) . '</span></li>';
                   
            }
               
        } elseif ( is_tag() ) {
               
            // Tag page
               
            // Get tag information
            $term_id        = get_query_var('tag_id');
            $taxonomy       = 'post_tag';
            $args           = 'include=' . $term_id;
            $terms          = get_terms( $taxonomy, $args );
            $get_term_id    = $terms[0]->term_id;
            $get_term_slug  = $terms[0]->slug;
            $get_term_name  = $terms[0]->name;
               
            // Display the tag name
            echo '<li class="item-current"><span class="active">' . esc_html( $get_term_name ) . '</span></li>';
           
        } elseif ( is_day() ) {
               
            // Day archive
               
            // Year link
            echo '<li class="item-year"><a class="bread-year" href="' . esc_url( get_year_link( get_the_time('Y') ) ) . '">' . esc_html( get_the_time('Y') ) . '</a></li>';
            //echo '<li class="separator separator-' . get_the_time('Y') . '"> ' . $separator . ' </li>';
               
            // Month link
            echo '<li class="item-month"><a class="bread-month" href="' . esc_url( get_month_link( get_the_time('Y'), get_the_time('m') ) ) . '">' . esc_html( get_the_time('M') ) . '</a></li>';
           // echo '<li class="separator separator-' . get_the_time('m') . '"> ' . $separator . ' </li>';
               
            // Day display
            echo '<li class="item-current"><span class="active bread-current"> ' . esc_html( get_the_time('jS') ) . ' ' . esc_html( get_the_time('M') ) . '</span></li>';
               
        } elseif ( is_month() ) {
               
            // Month Archive
               
            // Year link
            echo '<li class="item-year"><a class="bread-year" href="' . esc_url( get_year_link( get_the_time('Y') ) ) . '">' . esc_html( get_the_time('Y') ) . '</a></li>';
            //echo '<li class="separator separator-' . get_the_time('Y') . '"> ' . $separator . ' </li>';
               
            // Month display
            echo '<li class="item-month"><span class="active bread-month">' . esc_html( get_the_time('M') ) . '</span></li>';
               
        } elseif ( is_year() ) {
               
            // Display year archive
            echo '<li class="item-current"><span class="active bread-current">' . esc_html( get_the_time('Y') ) . ' </span></li>';
               
        } elseif ( is_author() ) {
               
            // Auhor archive
               
            // Get the author information
            global $author;
            $userdata = get_userdata( $author );

            /* translators: %s is replaced with "string". It will display the author name */
            echo '<li class="item-current"><span class="active bread-current">' . sprintf( esc_html__( 'Author: %s', 'hotelica' ) , esc_html( $userdata->display_name ) ) . '</span></li>';
           
        } elseif ( is_search() ) {
           
           $search_title = explode( ',' , get_search_query() );

            /* translators: %s is replaced with "string". It will display the search title */
            echo '<li class="item-current"><span class="active bread-current">' . sprintf( esc_html__( 'Search results for: %s' , 'hotelica' ) , esc_html( $search_title[0] ) ) . '</span></li>';
           
        } elseif ( is_404() ) {
               
            // 404 page
            echo '<li class="active">' . esc_html__( 'Error 404' , 'hotelica' ) . '</li>';
        } elseif( is_tax() ){

        	$term = get_term_by("slug", get_query_var("term"), get_query_var("taxonomy") );

	        $tmpTerm = $term;
	        $tmpCrumbs = array();
	        while ($tmpTerm->parent > 0){
	            $tmpTerm = get_term($tmpTerm->parent, get_query_var("taxonomy"));
	            $crumb = '<li><a href="' . esc_url( get_term_link($tmpTerm, get_query_var('taxonomy')) ) . '">' . esc_html( $tmpTerm->name ) . '</a></li>';
	            array_push($tmpCrumbs, $crumb);
	        }
	        echo implode('', array_reverse($tmpCrumbs));
	        echo '<li class="item-current item-cat"><span class="active bread-current bread-cat">' . esc_html( $term->name ) . '</span></li>';

        }
                  
    }
       
}

/**
* Displays the author name
*/

function hotelica_get_display_name( $post ){

	$user_id = $post->post_author;
	$user_info = get_userdata($user_id);
	echo esc_html( $user_info->display_name );

}

/**
* get the post categories in html format
*/

function hotelica_post_categories( $post ){
	$post_categories = wp_get_post_categories( $post->ID );
	$cats = array();
	foreach($post_categories as $c){
	    $cat = get_category( $c );
	    $cats[] = '<a href="' . esc_url( get_category_link( $cat ) ) . '">' . esc_html( $cat->name ) . '</a>';	    
	}
	echo implode( ' , ' , $cats);
	
}

add_filter( 'get_search_form', 'hotelica_search_form', 100 );
function hotelica_search_form( $form ) {
    $form = '<form role="search" method="get" id="search-form" class="search-form" action="' . esc_url( home_url( '/' ) ) . '" >
    	<label for="s">
    		<input placeholder="' . esc_attr__( 'Search ...' , 'hotelica' ) . '" type="text" value="' . esc_attr( get_search_query() ) . '" name="s" id="s" class="search-field" />
    		<input class="search-submit" type="submit" id="searchsubmit" value="'. esc_attr__( 'Search' , 'hotelica' ) .'" />
    	</label>    	
    </form>';

    return $form;
}

/**
* Pagination default
*/

if( !function_exists( 'hotelica_get_pagination_style' ) ){

	function hotelica_get_pagination_style(){
		the_posts_navigation( array( 'screen_reader_text' => '' ) );
	}
}

/**
* Sidebar options, right or left sidebar
*/

function hotelica_get_sidebar_position(){

	$position = get_theme_mod( 'sidebar_position' , 'right' );

	if( $position == 'left' ){
		return 'left';
	}
	return false;

}

function hotelica_get_banner_title(){
	return esc_html( get_theme_mod( 'banner_title' ) );
}
function hotelica_get_banner_subtitle(){
	return esc_html( get_theme_mod( 'banner_subtitle' ) );
}
function hotelica_get_about_us_title(){
	return esc_html( get_theme_mod( 'about_us_title' ) );
}
function hotelica_get_aboutus_subtitle(){
	return esc_html( get_theme_mod( 'about_us_subtitle' ) );
}
function hotelica_get_aboutus_content(){
	return wp_kses_post( get_theme_mod( 'about_us_content' ) );
}
function hotelica_get_room_listing_title(){
	return esc_html( get_theme_mod( 'room_listings_title' ) );
}
function hotelica_get_room_listing_subtitle(){
	return esc_html( get_theme_mod( 'room_listing_subtitle' ) );
}
function hotelica_room_listing_category(){
	ob_start();
	hotelica_get_rooms_homepage();
	return ob_get_clean();	
}
function hotelica_special_package_title(){
	return esc_html( get_theme_mod( 'special_package_title' ) );
}
function hotelica_special_offer_description(){
	return esc_html( get_theme_mod( 'special_offer_description' ) );
}
function hotelica_special_package_btn_text(){
	return esc_html( get_theme_mod( 'special_package_btn' ) );
}
function hotelica_packages_title(){
	return esc_html( get_theme_mod( 'packages_title' ) );
}
function hotelica_packages_subtitle(){
	return esc_html( get_theme_mod( 'packages_subtitle' ) );
}
function hotelica_testimonials_title(){
	return esc_html( get_theme_mod( 'testimonials_title' ) );
}
function hotelica_testimonials_subtitle(){
	return esc_html( get_theme_mod( 'testimonials_subtitle' ) );
}
function hotelica_facilities_title(){
	 return esc_html( get_theme_mod( 'facilities_title' ) );
}
function hotelica_facilities_subtitle(){
	return esc_html( get_theme_mod( 'facilities_subtitle' ) );
}
function hotelica_gallery_title(){
	return esc_html( get_theme_mod( 'gallery_title' ) );
}
function hotelica_gallery_subtitle(){
	return esc_html( get_theme_mod( 'gallery_subtitle' ) );
}
function hotelica_blog_title(){
	return esc_html( get_theme_mod( 'blog_title' ) );
}
function hotelica_blog_subtitle(){
	return esc_html( get_theme_mod( 'blog_subtitle' ) );
}
function hotelica_contact_us_title(){
	return esc_html( get_theme_mod( 'contact_us_title' ) );
}
function hotelica_contact_us_subtitle(){
	return esc_html( get_theme_mod( 'contact_us_subtitle' ) );
}
function hotelica_contact_us_details(){
	return wp_kses_post( get_theme_mod( 'contact_us_details' ) );
}
function hotelica_copyright_text(){
	return wp_kses_post( get_theme_mod( 'copyright_text' ) );
}

/**
* Homepage sections orders
*/

if( !function_exists( 'hotelica_get_order_homepage' ) ){

	function hotelica_get_order_homepage(){

		get_template_part( 'template-parts/homepage' , 'aboutus' );
		get_template_part( 'template-parts/homepage' , 'roomlist' );
		get_template_part( 'template-parts/homepage' , 'special-offer' );
		get_template_part( 'template-parts/homepage' , 'packages' );
		get_template_part( 'template-parts/homepage' , 'testimonials' );
		get_template_part( 'template-parts/homepage' , 'our-facilities' );
		get_template_part( 'template-parts/homepage' , 'gallery' );
		get_template_part( 'template-parts/homepage' , 'blog' );

	}
	
}

/**
* Copyright text in the footer
*/

if( !function_exists('hotelica_get_copyright_section') ){
	
	function hotelica_get_copyright_section(){

		esc_html_e( 'Copyright &copy;', 'hotelica' ); echo date_i18n( __( 'Y' , 'hotelica' ) ); ?> 
				
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php bloginfo( 'name' ); ?>">
			<?php bloginfo( 'name' ); ?>
		</a>

		<?php 

		esc_html_e( '. All rights reserved. ', 'hotelica' ); 

		printf( 
			esc_html__( 'Powered %1$s by %2$s', 'hotelica' ), 
			'', 
			'<a href="https://wordpress.org/" target="_blank">WordPress</a>' ); 
		?>

        <span class="sep"> &amp; </span>

        <?php esc_html_e( 'Designed by', 'hotelica' ); ?> 

        <a href="<?php echo esc_url( 'http://cyclonethemes.com/'); ?>" target="_blank">
        	<?php esc_html_e( 'Cyclone Themes', 'hotelica' ); ?>
        </a>

        <?php

	}

}

if( !function_exists('hotelica_get_footer') ){	
	function hotelica_get_footer(){ 
		hotelica_get_footer_1();
	}
}

/**
* This is the default footer
*/

function hotelica_get_footer_1(){ ?>
	
	<footer class="footer" id="footer">

		<div id="footer-bottom">

			<div id="newsletter" class=""></div>

			<div class="container">

				<?php 
				$social_links = get_theme_mod( 'footer_social_links' );			

				if( !empty( $social_links ) && is_array( $social_links ) ){
					$count = 0;
					?>
					<div class="footer-social">
						<?php 
						foreach ( $social_links as $value ) {
							$count += 0.3; 
							echo '<a class="wow fadeInUp" data-wow-offset="50" data-wow-delay="' . esc_attr( $count ) . 's" href="' . esc_url( $value['link'] ) . '"><i class="fa ' . esc_attr( $value['icon'] ) . '"></i></a>'; 	
						} ?>
					</div>
					<?php
				}
				?>	

				<ul class="inline-menu">
					<?php 
					wp_nav_menu( array(
					    'theme_location' => 'footer',
					) );?>
				</ul>

				<p class="text-center copyright_text">			

					<?php hotelica_get_copyright_section(); ?>
						
				</p>

			</div>

		</div>

	</footer>

	<?php
}

/**
* Demo files for import 
*/

add_filter( 'pt-ocdi/import_files', 'hotelica_import_files' );

function hotelica_import_files() {

  	return array(

    	array(

      		'import_file_name'             => esc_html__( 'Hotelica Content', 'hotelica' ),
	      	'local_import_file'            => esc_url( get_template_directory() . '/inc/data/demo-content.xml' ),
	      	'local_import_customizer_file' => esc_url( get_template_directory() . '/inc/data/customizer.dat' ),
	      	// 'local_import_widget_file' => esc_url( get_template_directory() . '/inc/data/widgets.wie' ),

    	),

  	);

}

if( function_exists( 'register_field_group' ) ){

	register_field_group(array (
		'id' => 'acf_package-custom-fields',
		'title' => esc_html__( 'Package Custom Fields' , 'hotelica' ),
		'fields' => array (
			array (
				'key' => 'field_5940f50e310d7',
				'label' => esc_html__( 'Price' , 'hotelica' ),
				'name' => 'price',
				'type' => 'number',
				'instructions' => esc_html__( 'Add your package price, you can change the currency from the Customizer. Default currency is USD' , 'hotelica' ),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => '',
				'max' => '',
				'step' => '',
			),
			array (
				'key' => 'field_594106bff8c83',
				'label' => esc_html__( 'Gallery' , 'hotelica' ),
				'name' => 'gallery',
				'type' => 'photo_gallery',
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'post',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));

}

// Create a helper function for easy SDK access.
function hotelica_fs() {
	
    global $hotelica_fs;

    if ( ! isset( $hotelica_fs ) ) {
        // Include Freemius SDK.
        require_once get_template_directory() . '/freemius/start.php';

        $hotelica_fs = fs_dynamic_init( array(
            'id'                  => '1106',
            'slug'                => 'hotelica',
            'type'                => 'theme',
            'public_key'          => 'pk_e0504e59a62f31e827950a5d5ceb0',
            'is_premium'          => false,
            'has_addons'          => false,
            'has_paid_plans'      => false,
            'menu'                => array(
                'account'        => false,
            ),
        ) );
    }

    return $hotelica_fs;
}

// Init Freemius.
hotelica_fs();
// Signal that SDK was initiated.
do_action( 'hotelica_fs_loaded' );

if ( is_admin() ) {
    // Load about.
    require_once trailingslashit( get_template_directory() ) . '/inc/theme-info/class-about.php';
    require_once trailingslashit( get_template_directory() ) . '/inc/theme-info/about.php';

    // Load demo.
    require_once trailingslashit( get_template_directory() ) . '/inc/demo/class-demo.php';
    require_once trailingslashit( get_template_directory() ) . '/inc/demo/demo.php';
}